<?php if (!defined('FOUNDATION_UI')) exit;

if (!isset($steps)) $steps = [];
if (!isset($version)) $version = null;

$version = true;

$this->steps = $steps;

$response = Foundation\Response::version(
    $version,
    function () use ($steps) {
        foreach ($steps as $step)
            $this['content.' . $step] = foundation_output($step);
        $this['steps'] = $steps;
        $this['render'] = true;
    }
);

if (!$steps = $response['steps'] or !count($steps))
    return;

$indexKey = is_admin() ? '#index' : 'index';

$index = $response->default($indexKey, 0);

$global->index = $index;
$global->step = $steps[$index];
$global->last = ($index + 1) === count($steps);
$global->first = $index === 0;

$trail = $trail2 = $response['trail'];

if ($trail === null)
    $trail = [];

if (!in_array($global->step, $trail))
    $trail[sanitize_title($global->step)] = $global->step;

if ($trail2 === null or count($trail) !== count($trail2))
    $response['trail'] = $trail;

$global->trail = $trail;

if (!is_numeric($index) or !isset($steps[$index]))
    $index = $response->set($indexKey, 0);

$step = isset($steps[$index]) ? $steps[$index] : '';

if (!$step) $step = ' ';

if (!$output = $response['content.' . $step]) {
    // $output = foundation_output($step);
}

$state = $response->merge(
    'state',
    [
        'index' => $index,
        'form_step' => sanitize_title($step),
        'form_steps' => count($steps),
        'form_trail' => $global->trail
    ],
    false
);

if (!is_admin()) : ?>
    <form prefix="<?= sanitize_title($step) ?>" id="form">
        <?= $output ? $output : '' ?>
    </form>

    <div style="color: transparent"><?php echo $step ?></div>
<?php

else : ?>
    <div>
        <button-group style="float: right">
            <?php if ($index) : ?>
                <button on-click="api.post(back: true)">Back</button>
            <?php endif ?>
            <button on-click="post(next: true)">Next</button>
        </button-group>
        <h3><?= $step ?></h3>
    </div>
    <form prefix="<?= sanitize_title($step) ?>" id="form">
        <?= $output ? $output : '' ?>
    </form>
    <button intent="primary" on-click="submit">
        Save Changes
    </button>
<?php

endif;

return [
    'GET?reset' => function () use ($response, $indexKey) {
        unset($response[$indexKey]);
        return true;
    },
    'POST?back' => function () use ($response, $indexKey) {
        $response->decr($indexKey);
        return true;
    },
    'POST?next' => function () use ($response, $indexKey) {
        $index = $response->incr($indexKey);

        return true;
    },
    'POST?jump' => function ($jump) use ($response, $indexKey, $steps) {
        foreach ($steps as $index => $step) {
            if ($jump === $step or $jump === sanitize_title($step)) {
                $response[$indexKey] = $index;
            }
        }
        return true;
    },
    'POST' => function () use ($response, $indexKey) {
        $response->merge('state', PandaRoseUI::$in);
        $index = $response->incr($indexKey);
        $response->save();

        return true;
    },
    'state' => $state,
];
